/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.model

import android.os.Parcelable
import com.google.gson.annotations.SerializedName
import com.kakao.sdk.partner.friend.Constants
import kotlinx.parcelize.Parcelize

/**
 * @property selectionType 채팅방 피커 종류, CHAT 또는 CHAT_MEMBER 선택(필수)
 * @property title 채팅방 피커의 타이틀 영역에 표시될 텍스트
 * @property pickerChatFilters 채팅방 피커에 포함할 채팅방 타입
 * @property viewAppearance 채팅방 피커 모드
 * @property orientation 채팅방 피커의 방향
 * @property enableSearch 검색 기능 사용 여부
 * @property showFriendsOnly 채팅방 멤버 피커에서 친구만 표시
 * @property displayAllProfile 앱과 연결되지 않았거나 동의 항목에 미동의한 사용자의 프로필 전체 정보 표시 여부
 * @property disableSelectReasons 사용자 선택 불가 사유 표시
 * @property maxPickableCount 선택 가능한 채팅방 멤버 수의 최대값
 * @property minPickableCount 선택 가능한 채팅방 멤버 수의 최소값
 */
@Parcelize
class PickerChatRequestParams(
    val selectionType: PickerChatSelectionType,
    val title: String? = null,
    val pickerChatFilters: List<PickerChatFilter>? = listOf(Constants.DEFAULT_PICKER_CHAT_FILTER),
    val viewAppearance: ViewAppearance? = Constants.DEFAULT_PICKER_VIEW_APPEARANCE,
    val orientation: PickerOrientation? = Constants.DEFAULT_PICKER_ORIENTATION,
    val enableSearch: Boolean? = Constants.DEFAULT_ENABLE_SEARCH,
    val showFriendsOnly: Boolean? = false,
    val displayAllProfile: Boolean? = false,
    val disableSelectReasons: List<DisableSelectReason>? = null,
    val maxPickableCount: Int? = Constants.DEFAULT_MAX_PICKABLE_COUNT,
    val minPickableCount: Int? = Constants.DEFAULT_MIN_PICKABLE_COUNT
) : Parcelable

/**
 * 채팅방 피커 종류 선택
 */
enum class PickerChatSelectionType {
    /**
     * 채팅방 피커
     */
    CHAT,

    /**
     * 채팅방 멤버 피커
     */
    CHAT_MEMBER
}

/**
 * 채팅방 목록 필터링 옵션
 */
enum class PickerChatFilter(val value: String) {
    /**
     *  1:1 채팅방만 필터링하여 결과에 포함시킵니다.
     */
    @SerializedName("direct")
    DIRECT("direct"),

    /**
     * 그룹 채팅방만 필터링하여 결과에 포함시킵니다.
     */
    @SerializedName("multi")
    MULTI("multi"),

    /**
     * 일반 채팅방만 필터링하여 결과에 포함시킵니다.
     */
    @SerializedName("regular")
    REGULAR("regular"),

    /**
     * 오픈 채팅방만 필터링하여 결과에 포함시킵니다.
     */
    @SerializedName("open")
    OPEN("open");
}