/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.viewmodel

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel

/**
 * @suppress
 */
internal class TabViewModel : ViewModel() {
    var tabPosition = 0
        private set

    private val _pickedFriendsCount = MutableLiveData<Int>()
    val pickedFriendsCount: LiveData<Int> get() = _pickedFriendsCount

    private val _isDoneButtonEnabled = MutableLiveData<Boolean>()
    val isDoneButtonEnabled: LiveData<Boolean> get() = _isDoneButtonEnabled

    private val _friendStatus = MutableLiveData<TabStatus>()
    val friendStatus: LiveData<TabStatus> get() = _friendStatus

    private val _chatStatus = MutableLiveData<TabStatus>()
    val chatStatus: LiveData<TabStatus> get() = _chatStatus

    private val _isEmptyFriendError = MutableLiveData<Boolean>()
    val isEmptyFriendError: LiveData<Boolean> get() = _isEmptyFriendError

    private val _isEmptyChatError = MutableLiveData<Boolean>()
    val isEmptyChatError: LiveData<Boolean> get() = _isEmptyChatError

    fun setPickedCount(count: Int) {
        if (tabPosition == 0) {
            _isDoneButtonEnabled.value = count > 0
        }
        _pickedFriendsCount.value = count
    }

    fun setChatPicked(isPicked: Boolean) {
        if (tabPosition == 1) {
            _isDoneButtonEnabled.value = isPicked
        }
    }

    fun sendResult() {
        if (tabPosition == 0) {
            _friendStatus.value = TabStatus.DONE
            _friendStatus.value = TabStatus.READY
        } else {
            _chatStatus.value = TabStatus.DONE
            _chatStatus.value = TabStatus.READY
        }
    }

    fun cancelPicker() {
        if (tabPosition == 0) {
            _friendStatus.value = TabStatus.CANCELED
        } else {
            _chatStatus.value = TabStatus.CANCELED
        }
    }

    fun clearTab(position: Int) {
        if (position != tabPosition) {
            _isDoneButtonEnabled.value = false
            tabPosition = position
        }
        // 탭 위치와 반대로 데이터를 초기화해줘야함
        if (position == 0) {
            _chatStatus.value = TabStatus.CLEARED
            _chatStatus.value = TabStatus.READY
        } else {
            _friendStatus.value = TabStatus.CLEARED
            _friendStatus.value = TabStatus.READY
        }
    }

    fun setEmptyFriendError(isEmpty: Boolean) {
        _isEmptyFriendError.value = isEmpty
    }

    fun setEmptyChatError(isEmpty: Boolean) {
        _isEmptyChatError.value = isEmpty
    }
}